@@ -158,7 +158,7 @@ public interface FieldDescription extends ByteCodeElement,
 
         @Override
         public int hashCode() {
-            return getDeclaringType().hashCode() + 31 * getName().hashCode();
+            return getDeclaringType().hashCode() + 31 * (17 + getName().hashCode());
         }
 
         @Override
@@ -205,6 +205,9 @@ public interface FieldDescription extends ByteCodeElement,
 
         @Override
         public TypeDescription.Generic getType() {
+            if (TypeDescription.AbstractBase.RAW_TYPES) {
+                return new TypeDescription.Generic.OfNonGenericType.ForLoadedType(field.getType());
+            }
             return new TypeDescription.Generic.LazyProjection.ForLoadedFieldType(field);
         }
 
