@@ -695,6 +695,11 @@ public interface Implementation extends InstrumentedType.Prepareable {
              */
             private final Map<FieldCacheEntry, FieldDescription.InDefinedShape> registeredFieldCacheEntries;
 
+            /**
+             * A set of registered field cache entries.
+             */
+            private final Set<FieldDescription.InDefinedShape> registeredFieldCacheFields;
+
             /**
              * A random suffix to append to the names of accessor methods.
              */
@@ -728,6 +733,7 @@ public interface Implementation extends InstrumentedType.Prepareable {
                 registeredSetters = new HashMap<FieldDescription, DelegationRecord>();
                 auxiliaryTypes = new HashMap<AuxiliaryType, DynamicType>();
                 registeredFieldCacheEntries = new HashMap<FieldCacheEntry, FieldDescription.InDefinedShape>();
+                registeredFieldCacheFields = new HashSet<FieldDescription.InDefinedShape>();
                 suffix = RandomString.make();
                 fieldCacheCanAppendEntries = true;
             }
@@ -795,7 +801,7 @@ public interface Implementation extends InstrumentedType.Prepareable {
                 int hashCode = fieldValue.hashCode();
                 do {
                     fieldCache = new CacheValueField(instrumentedType, fieldType.asGenericType(), suffix, hashCode++);
-                } while (registeredFieldCacheEntries.values().contains(fieldCache));
+                } while (!registeredFieldCacheFields.add(fieldCache));
                 registeredFieldCacheEntries.put(fieldCacheEntry, fieldCache);
                 return fieldCache;
             }
