@@ -758,13 +758,11 @@ public abstract class AbstractMethodDescriptionTest {
 
     @Test
     public void testSyntethicParameter() throws Exception {
-        Constructor<?> constructor = null;
-        for (Constructor<?> candidate : SyntheticParameter.class.getDeclaredConstructors()) {
-            if (candidate.getParameterTypes().length == 2) {
-                constructor = candidate;
-            }
-        }
-        assertThat(describe(constructor).getParameters().get(1).getDeclaredAnnotations().isAnnotationPresent(Deprecated.class), is(true));
+        assertThat(describe(SyntheticParameter.class.getDeclaredConstructor(AbstractMethodDescriptionTest.class, Void.class))
+                .getParameters()
+                .get(1)
+                .getDeclaredAnnotations()
+                .isAnnotationPresent(Deprecated.class), is(true));
     }
 
     @Test
