@@ -101,7 +101,8 @@ public abstract class AbstractTypeDescriptionTest extends AbstractTypeDescriptio
                 EnclosingType.FINAL_INNER,
                 Array.newInstance(EnclosingType.FINAL_INNER, 1).getClass(),
                 EnclosingType.DEPRECATED,
-                Array.newInstance(EnclosingType.DEPRECATED, 1).getClass());
+                Array.newInstance(EnclosingType.DEPRECATED, 1).getClass(),
+                Type$With$Dollar.class);
     }
 
     @Test
@@ -805,4 +806,8 @@ public abstract class AbstractTypeDescriptionTest extends AbstractTypeDescriptio
             /* empty */
         }
     }
+
+    private static class Type$With$Dollar {
+        /* */
+    }
 }
